@@ -8,10 +8,11 @@ import numpy
 
 import cf
 
+
 class Field_collapseTest(unittest.TestCase):
     def setUp(self):
-        self.filename2 = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                                      'test_file2.nc')
+        self.filename2 = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)), 'test_file2.nc')
 
         self.chunk_sizes = (17, 50, 100, 300, 3000, 300000)[::-1]
         self.original_chunksize = cf.CHUNKSIZE()
@@ -36,17 +37,20 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 4
 
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
-        g = f.collapse('T: max within years time: minimum over years', within_years=cf.seasons())
+        g = f.collapse(
+            'T: max within years time: minimum over years',
+            within_years=cf.seasons()
+        )
         expected_shape = list(f.shape)
         expected_shape[0] = 4
 
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -57,17 +61,20 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 12
 
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
 
-        g = f.collapse('T: max within years time: minimum over years', within_years=cf.M())
+        g = f.collapse(
+            'T: max within years time: minimum over years',
+            within_years=cf.M()
+        )
         expected_shape = list(f.shape)
         expected_shape[0] = 12
 
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -78,7 +85,7 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 4
 
         if verbose:
-            print('\n',f[:12])
+            print('\n', f[:12])
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -89,7 +96,7 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 4
 
         if verbose:
-            print('\n',f[:12])
+            print('\n', f[:12])
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -100,7 +107,7 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 12
 
         if verbose:
-            print('\n',f[:12])
+            print('\n', f[:12])
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -111,7 +118,7 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 12
 
         if verbose:
-            print('\n',f[:12])
+            print('\n', f[:12])
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -125,17 +132,18 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 4
 
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
 
-        g = f.collapse('T: max within years time: min over years', within_years=cf.M())
+        g = f.collapse(
+            'T: max within years time: min over years', within_years=cf.M())
         expected_shape = list(f.shape)
         expected_shape[0] = 12
 
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -146,7 +154,7 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 4
 
         if verbose:
-            print('\n',f[:12])
+            print('\n', f[:12])
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -157,7 +165,7 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 12
 
         if verbose:
-            print('\n',f[:12])
+            print('\n', f[:12])
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -168,18 +176,20 @@ class Field_collapseTest(unittest.TestCase):
         expected_shape[0] = 8
 
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
 
-        g = f[::-1, ...].collapse('T: max within years time: minimum over years',
-                                  within_years=cf.seasons(), over_years=cf.Y(2))
+        g = f[::-1, ...].collapse(
+            'T: max within years time: minimum over years',
+            within_years=cf.seasons(), over_years=cf.Y(2)
+        )
         expected_shape = list(f.shape)
         expected_shape[0] = 8
 
         if verbose:
-            print('\n',f[::-1, ...])
+            print('\n', f[::-1, ...])
             print(g)
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape)
@@ -194,14 +204,14 @@ class Field_collapseTest(unittest.TestCase):
 
         g = f.collapse('mean')
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1, 1, 1), g.shape)
 
         g = f.collapse('mean', axes=['T', 'X'])
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1, 4, 1))
@@ -209,56 +219,56 @@ class Field_collapseTest(unittest.TestCase):
         g = f.collapse('mean', axes=[0, 2])
 
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1, 4, 1))
 
         g = f.collapse('mean', axes=[0, 1])
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1, 1, 5))
 
         g = f.collapse('mean', axes='domainaxis1')
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1800, 1, 5))
 
         g = f.collapse('mean', axes=['domainaxis1'])
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1800, 1, 5))
 
         g = f.collapse('mean', axes=[1])
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1800, 1, 5))
 
         g = f.collapse('mean', axes=1)
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1800, 1, 5))
 
         g = f.collapse('T: mean')
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1, 4, 5))
 
         g = f.collapse('T: mean X: maximum')
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (1, 4, 1))
@@ -266,14 +276,15 @@ class Field_collapseTest(unittest.TestCase):
         g = f.collapse('T: mean within years time: minimum over years',
                        within_years=cf.M())
         if verbose:
-            print('\n',f)
+            print('\n', f)
             print(g)
             print(g.constructs)
         self.assertTrue(g.shape == (12, 4, 5))
 
         for m in range(1, 13):
             a = numpy.empty((5, 4, 5))
-            for i, year in enumerate(f.subspace(T=cf.month(m)).coord('T').year.unique()):
+            for i, year in enumerate(
+                    f.subspace(T=cf.month(m)).coord('T').year.unique()):
                 q = cf.month(m) & cf.year(year)
                 x = f.subspace(T=cf.month(m) & cf.year(year))
                 x.data.mean(axes=0, inplace=True)
@@ -291,10 +302,15 @@ class Field_collapseTest(unittest.TestCase):
                       cf.M(12, month=11, day=27)):
             g = f.collapse('T: mean', group=group)
             bound = g.coord('T').bounds.datetime_array[0, 1]
-            self.assertTrue(bound.month == group.offset.month,
-                            "{}!={}, group={}".format(bound.month, group.offset.month, group))
-            self.assertTrue(bound.day   == group.offset.day,
-                            "{}!={}, group={}".format(bound.day, group.offset.day, group))
+            self.assertTrue(
+                bound.month == group.offset.month,
+                "{}!={}, group={}".format(
+                    bound.month, group.offset.month, group)
+            )
+            self.assertTrue(
+                bound.day == group.offset.day,
+                "{}!={}, group={}".format(bound.day, group.offset.day, group)
+            )
         # --- End: for
 
 #            for group in (cf.D(30),
@@ -303,8 +319,11 @@ class Field_collapseTest(unittest.TestCase):
 #                          cf.D(30, month=11, day=27)):
 #                g = f.collapse('T: mean', group=group)
 #                bound = g.coord('T').bounds.datetime_array[0, 1]
-#                self.assertTrue(bound.day == group.offset.day,
-#                                "{}!={}, bound={}, group={}".format(bound.day, group.offset.day, bound, group))
+#                self.assertTrue(
+#                    bound.day == group.offset.day,
+#                    "{}!={}, bound={}, group={}".format(
+#                        bound.day, group.offset.day, bound, group)
+#                )
 
     def test_Field_collapse_WEIGHTS(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
@@ -360,7 +379,8 @@ class Field_collapseTest(unittest.TestCase):
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
-        g = f.collapse('T: mean', group=cf.M(12, month=11, day=27), group_span=cf.Y())
+        g = f.collapse(
+            'T: mean', group=cf.M(12, month=11, day=27), group_span=cf.Y())
         expected_shape = list(f.shape)
         expected_shape[0] = 3
 
@@ -370,40 +390,53 @@ class Field_collapseTest(unittest.TestCase):
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
-        g = f.collapse('T: mean', group=cf.M(12, month=6, day=27), group_span=cf.Y())
+        g = f.collapse(
+            'T: mean', group=cf.M(12, month=6, day=27), group_span=cf.Y())
         expected_shape = list(f.shape)
         expected_shape[0] = 2
 
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
-        g = f.collapse('T: mean', group=cf.M(5, month=12), group_span=cf.M(5), group_contiguous=1)
+        g = f.collapse(
+            'T: mean', group=cf.M(5, month=12), group_span=cf.M(5),
+            group_contiguous=1
+        )
         expected_shape = list(f.shape)
         expected_shape[0] = 7
 
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
-        g = f.collapse('T: mean', group=cf.M(5, month=12), group_span=cf.M(5), group_contiguous=1)
+        g = f.collapse(
+            'T: mean', group=cf.M(5, month=12), group_span=cf.M(5),
+            group_contiguous=1
+        )
         expected_shape = list(f.shape)
         expected_shape[0] = 7
 
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
-        g = f.collapse('T: mean', group=cf.M(5, month= 3), group_span=cf.M(5),
+        g = f.collapse('T: mean', group=cf.M(5, month=3), group_span=cf.M(5),
                        group_contiguous=1)
         expected_shape = list(f.shape)
         expected_shape[0] = 7
@@ -411,7 +444,9 @@ class Field_collapseTest(unittest.TestCase):
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
@@ -423,7 +458,9 @@ class Field_collapseTest(unittest.TestCase):
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
@@ -435,7 +472,9 @@ class Field_collapseTest(unittest.TestCase):
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
@@ -446,9 +485,12 @@ class Field_collapseTest(unittest.TestCase):
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
-        self.assertTrue(list(g.shape) == expected_shape, g.shape) # TODO - look into month offset when M< 12
+        self.assertTrue(list(g.shape) == expected_shape, g.shape)
+        # TODO - look into month offset when M< 12
 
         g = f.collapse('T: mean', group=cf.M(5, month=3), group_span=cf.M(5),
                        group_contiguous=2)
@@ -458,7 +500,9 @@ class Field_collapseTest(unittest.TestCase):
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
@@ -469,18 +513,22 @@ class Field_collapseTest(unittest.TestCase):
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
-        g = f.collapse('T: mean', group=cf.M(5, month= 3), group_contiguous=1)
+        g = f.collapse('T: mean', group=cf.M(5, month=3), group_contiguous=1)
         expected_shape = list(f.shape)
         expected_shape[0] = 7
 
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
@@ -491,18 +539,22 @@ class Field_collapseTest(unittest.TestCase):
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
-        g = f.collapse('T: mean', group=cf.M(5, month= 3), group_contiguous=2)
+        g = f.collapse('T: mean', group=cf.M(5, month=3), group_contiguous=2)
         expected_shape = list(f.shape)
         expected_shape[0] = 7
 
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
@@ -514,7 +566,9 @@ class Field_collapseTest(unittest.TestCase):
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
@@ -526,7 +580,9 @@ class Field_collapseTest(unittest.TestCase):
         if verbose:
             print(f)
             print(g)
-            print(g.dimension_coordinates('T').value().bounds.data.datetime_array)
+            print(
+                g.dimension_coordinates('T').value().bounds.data.datetime_array
+            )
             print(g.constructs)
         self.assertTrue(list(g.shape) == expected_shape, g.shape)
 
@@ -542,6 +598,7 @@ class Field_collapseTest(unittest.TestCase):
 
 # --- End: class
 
+
 if __name__ == '__main__':
     print('Run date:', datetime.datetime.now())
     cf.environment()
