@@ -14,16 +14,28 @@ class functionTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        for n in range(5):
+        for n in range(7):
             f = cf.example_field(n)
-            a = f.array
-            d = f.dump(display=False)
-            
+            _ = f.array
+            _ = f.dump(display=False)
+
         with self.assertRaises(Exception):
             _ = cf.example_field(-999)
 
-            
-#--- End: class
+    def test_keyword_deprecation(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        # Use as test case 'i' kwarg, the deprecated old name for 'inplace':
+        a = cf.Data([list(range(100))])
+        a.squeeze(inplace=True)  # new way to specify operation tested below
+
+        b = cf.Data([list(range(100))])
+        with self.assertRaises(cf.functions.DeprecationError):
+            b.squeeze(i=True)
+
+
+# --- End: class
 
 if __name__ == '__main__':
     print('Run date:', datetime.datetime.utcnow())
