@@ -44,13 +44,69 @@ class read_writeTest(unittest.TestCase):
 
     test_only = []
 #    test_only = ['NOTHING!!!!!']
-#    test_only = ['test_write_reference_datetime']
+#    test_only = ['test_write_filename']
 #    test_only = ['test_read_write_unlimited']
-#    test_only = ['test_read_write_format']
+#    test_only = ['test_write_datatype']
 #    test_only = ['test_read_directory']
 #    test_only = ['test_read_string']
 #    test_only = ['test_read_write_netCDF4_compress_shuffle']
 
+    def test_write_filename(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        tmpfile = tempfile.mktemp('.cf_test')
+        tmpfiles.append(tmpfile)
+        
+        f = cf.example_field(0)
+        a = f.array
+        
+        cf.write(f, tmpfile)
+        g = cf.read(tmpfile)
+
+        with self.assertRaises(Exception):
+            cf.write(g, tmpfile)
+
+        self.assertTrue((a == g[0].array).all())
+            
+    def test_read_mask(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return        
+
+        f = cf.example_field(0)
+
+        N = f.size
+        
+        f.data[1, 1] = cf.masked
+        f.data[2, 2] = cf.masked
+
+        f.del_property('_FillValue', None)
+        f.del_property('missing_value', None)
+        
+        cf.write(f, tmpfile)
+
+        g = cf.read(tmpfile)[0]
+        self.assertTrue(numpy.ma.count(g.data.array) == N - 2)
+        
+        g = cf.read(tmpfile, mask=False)[0]
+        self.assertTrue(numpy.ma.count(g.data.array) == N)
+
+        g.apply_masking(inplace=True)
+        self.assertTrue(numpy.ma.count(g.data.array) == N - 2)
+        
+        f.set_property('_FillValue', 999)
+        f.set_property('missing_value', -111)
+        cf.write(f, tmpfile)
+        
+        g = cf.read(tmpfile)[0]
+        self.assertTrue(numpy.ma.count(g.data.array) == N - 2)
+        
+        g = cf.read(tmpfile, mask=False)[0]
+        self.assertTrue(numpy.ma.count(g.data.array) == N)
+
+        g.apply_masking(inplace=True)
+        self.assertTrue(numpy.ma.count(g.data.array) == N - 2)
+
     def test_read_directory(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -117,7 +173,8 @@ class read_writeTest(unittest.TestCase):
         # select on field list
         f = cf.read(self.filename, select='eastward_wind')
         g = cf.read(self.filename)
-        self.assertTrue(f.equals(g, verbose=True), 'Bad read with select keyword')
+        self.assertTrue(f.equals(g, verbose=True),
+                        'Bad read with select keyword')
 
     def test_read_squeeze(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
@@ -159,11 +216,15 @@ class read_writeTest(unittest.TestCase):
         f = cf.read(filename, extra='domain_ancillary', verbose=0)
         self.assertTrue(len(f) == 4, '\n'+str(f))
 
-        f = cf.read(filename, extra=['field_ancillary', 'auxiliary_coordinate'])
+        f = cf.read(filename, extra=['field_ancillary',
+                                     'auxiliary_coordinate'])
         self.assertTrue(len(f) == 8, '\n'+str(f))
 
-        self.assertTrue(len(cf.read(filename, extra=['domain_ancillary', 'auxiliary_coordinate'])) == 7)
-        f = cf.read(filename, extra=['domain_ancillary', 'cell_measure', 'auxiliary_coordinate'])
+        self.assertTrue(len(cf.read(filename,
+                                    extra=['domain_ancillary',
+                                           'auxiliary_coordinate'])) == 7)
+        f = cf.read(filename, extra=['domain_ancillary', 'cell_measure',
+                                     'auxiliary_coordinate'])
         self.assertTrue(len(f) == 8, '\n'+str(f))
 
         f = cf.read(filename, extra=('field_ancillary', 'dimension_coordinate',
@@ -193,14 +254,16 @@ class read_writeTest(unittest.TestCase):
                     self.assertTrue(len(g) == 1, 'g = '+repr(g))
                     g0 = g[0]
 
-                    self.assertTrue(f0.equals(g0, verbose=1),
-                                    'Bad read/write of format {!r}'.format(fmt))
+                    self.assertTrue(
+                        f0.equals(g0, verbose=1),
+                        'Bad read/write of format {!r}'.format(fmt))
 
     def test_read_write_netCDF4_compress_shuffle(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        tmpfile = tempfile.mktemp('.cf-python_test')
+        tmpfile = tempfile.mktemp('.cf_test')
+        tmpfiles.append(tmpfile)
 
         for chunksize in self.chunk_sizes:
             cf.CHUNKSIZE(chunksize)
@@ -216,7 +279,8 @@ class read_writeTest(unittest.TestCase):
                         g = cf.read(tmpfile)[0]
                         self.assertTrue(
                             f.equals(g, verbose=True),
-                            'Bad read/write with lossless compression: {0}, {1}, {2}'.format(
+                            "Bad read/write with lossless compression: "
+                            "{0}, {1}, {2}".format(
                                 fmt, compress, shuffle))
         # --- End: for
         cf.CHUNKSIZE(self.original_chunksize)
@@ -225,6 +289,9 @@ class read_writeTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
+        tmpfile = tempfile.mktemp('.cf_test')
+        tmpfiles.append(tmpfile)
+        
         for chunksize in self.chunk_sizes:
             cf.CHUNKSIZE(chunksize)
             f = cf.read(self.filename)[0]
@@ -234,9 +301,41 @@ class read_writeTest(unittest.TestCase):
             g = cf.read(tmpfile)[0]
             self.assertTrue(g.dtype == numpy.dtype('float32'),
                             'datatype read in is '+str(g.dtype))
-        # --- End: for
+
         cf.CHUNKSIZE(self.original_chunksize)
 
+        # Keyword single
+        f = cf.read(self.filename)[0]
+        self.assertTrue(f.dtype == numpy.dtype(float))
+        cf.write(f, tmpfile, fmt='NETCDF4', single=True)
+        g = cf.read(tmpfile)[0]
+        self.assertTrue(g.dtype == numpy.dtype('float32'),
+                        'datatype read in is '+str(g.dtype))
+
+        tmpfile2 = tempfile.mktemp('.cf_test')
+        tmpfiles.append(tmpfile2)
+        
+        # Keyword double
+        f = g
+        self.assertTrue(f.dtype == numpy.dtype('float32'))
+        cf.write(f, tmpfile2, fmt='NETCDF4', double=True)
+        g = cf.read(tmpfile2)[0]
+        self.assertTrue(g.dtype == numpy.dtype(float),
+                        'datatype read in is '+str(g.dtype))
+
+        for single in (True, False):
+            for dousble in (True, False):
+                with self.assertRaises(Exception):
+                    _ = cf.write(g, double=double, single=single)
+        # --- End: for
+        
+        datatype = {numpy.dtype(float): numpy.dtype('float32')}
+        with self.assertRaises(Exception):
+            _ = cf.write(g, datatype=datatype, single=True)
+        
+        with self.assertRaises(Exception):
+            _ = cf.write(g, datatype=datatype, double=True)
+        
     def test_write_reference_datetime(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -245,16 +344,20 @@ class read_writeTest(unittest.TestCase):
             for chunksize in self.chunk_sizes:
                 cf.CHUNKSIZE(chunksize)
                 f = cf.read(self.filename)[0]
-                t = cf.DimensionCoordinate(data=cf.Data(123, 'days since 1750-1-1'))
+                t = cf.DimensionCoordinate(data=cf.Data(
+                    123, 'days since 1750-1-1'))
 
                 t.standard_name = 'time'
                 axisT = f.set_construct(cf.DomainAxis(1))
                 f.set_construct(t, axes=[axisT])
-                cf.write(f, tmpfile, fmt='NETCDF4', reference_datetime=reference_datetime)
+                cf.write(f, tmpfile, fmt='NETCDF4',
+                         reference_datetime=reference_datetime)
                 g = cf.read(tmpfile)[0]
                 t = g.dimension_coordinate('T')
-                self.assertTrue(t.Units == cf.Units('days since '+reference_datetime),
-                                'Units written were '+repr(t.Units.reftime)+' not '+repr(reference_datetime))
+                self.assertTrue(
+                    t.Units == cf.Units('days since '+reference_datetime),
+                    ('Units written were '+repr(t.Units.reftime)
+                     +' not '+repr(reference_datetime)))
         # --- End: for
         cf.CHUNKSIZE(self.original_chunksize)
 
@@ -312,12 +415,15 @@ class read_writeTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        subprocess.run(' '.join(['ncdump', self.filename, '>', tmpfile]),
-                       shell=True, check=True)
-        subprocess.run(' '.join(['ncdump', '-h', self.filename, '>', tmpfileh]),
-                                shell=True, check=True)
-        subprocess.run(' '.join(['ncdump', '-c', self.filename, '>', tmpfilec]),
-                       shell=True, check=True)
+        subprocess.run(
+            ' '.join(['ncdump', self.filename, '>', tmpfile]),
+            shell=True, check=True)
+        subprocess.run(
+            ' '.join(['ncdump', '-h', self.filename, '>', tmpfileh]),
+            shell=True, check=True)
+        subprocess.run(
+            ' '.join(['ncdump', '-c', self.filename, '>', tmpfilec]),
+            shell=True, check=True)
 
         f0 = cf.read(self.filename)[0]
         f = cf.read(tmpfile)[0]
@@ -326,11 +432,13 @@ class read_writeTest(unittest.TestCase):
 
         self.assertTrue(f0.equals(f, verbose=True))
 
-        self.assertTrue(f.construct('grid_latitude').equals(c.construct('grid_latitude'), verbose=True))
-        self.assertTrue(f0.construct('grid_latitude').equals(c.construct('grid_latitude'), verbose=True))
+        self.assertTrue(f.construct('grid_latitude').equals(
+            c.construct('grid_latitude'), verbose=True))
+        self.assertTrue(f0.construct('grid_latitude').equals(
+            c.construct('grid_latitude'), verbose=True))
 
         with self.assertRaises(Exception):
-            x = cf.read('test_read_write.py')
+            _ = cf.read('test_read_write.py')
 
     def test_read_write_string(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
